# vhlsrs

It means Vivado HLS run synthesis.

This package contains a script that runs vivado synthesis in a (somewhat)
reproducible way.

It also allow to search for the minimum pipeline depth design for a given clock
period constrain.
